@@ -13,9 +13,14 @@
 
 
 import pytest
+from botocore.config import Config
 from botocore.exceptions import FlexibleChecksumError
 
 from tests import ClientHTTPStubber, patch_load_service_model
+from tests.functional.test_useragent import (
+    get_captured_ua_strings,
+    parse_registered_feature_ids,
+)
 
 TEST_CHECKSUM_SERVICE_MODEL = {
     "version": "2.0",
@@ -148,7 +153,7 @@ TEST_CHECKSUM_RULESET = {
 }
 
 
-def setup_test_client(patched_session, monkeypatch):
+def setup_test_client(patched_session, monkeypatch, config=None):
     patch_load_service_model(
         patched_session,
         monkeypatch,
@@ -156,8 +161,7 @@ def setup_test_client(patched_session, monkeypatch):
         TEST_CHECKSUM_RULESET,
     )
     return patched_session.create_client(
-        "testservice",
-        region_name="us-west-2",
+        "testservice", region_name="us-west-2", config=config
     )
 
 
@@ -524,3 +528,89 @@ def test_unsuccessful_streaming_response_checksum_validation(
             expected_checksum,
         )
         assert str(expected_error.value) == error_msg
+
+
+def _checksum_user_agent_feature_id_cases():
+    request_payload = "Hello world"
+    return [
+        (None, None, None, request_payload, ["W", "b", "Z"]),
+        (
+            "CRC32",
+            "when_required",
+            "when_required",
+            request_payload,
+            ["U", "a", "c"],
+        ),
+        (
+            "SHA1",
+            "when_supported",
+            "when_supported",
+            request_payload,
+            ["X", "Z", "b"],
+        ),
+        (
+            "SHA256",
+            "when_supported",
+            "when_required",
+            request_payload,
+            ["Y", "Z", "c"],
+        ),
+        (
+            "SHA1",
+            "when_required",
+            "when_supported",
+            request_payload,
+            ["X", "a", "b"],
+        ),
+        (
+            "CRC32C",
+            None,
+            None,
+            request_payload,
+            ["V", "Z", 'b'],
+        ),
+        (
+            "CRC64NVME",
+            None,
+            "when_required",
+            request_payload,
+            ["W", "Z", "c"],
+        ),
+    ]
+
+
+@pytest.mark.parametrize(
+    "checksum_algorithm, checksum_calculation, checksum_validation, request_payload, expected_feature_ids",
+    _checksum_user_agent_feature_id_cases(),
+)
+def test_user_agent_has_checksum_request_feature_id(
+    patched_session,
+    monkeypatch,
+    checksum_algorithm,
+    checksum_calculation,
+    checksum_validation,
+    request_payload,
+    expected_feature_ids,
+):
+    client = setup_test_client(
+        patched_session,
+        monkeypatch,
+        config=Config(
+            request_checksum_calculation=checksum_calculation,
+            response_checksum_validation=checksum_validation,
+        ),
+    )
+
+    with ClientHTTPStubber(client, strict=True) as http_stubber:
+        http_stubber.add_response(
+            status=200,
+            body=b"<response/>",
+        )
+        operation_kwargs = {"body": request_payload}
+        if checksum_algorithm:
+            operation_kwargs["checksumAlgorithm"] = checksum_algorithm
+        client.http_checksum_streaming_operation(**operation_kwargs)
+    ua_string = get_captured_ua_strings(http_stubber)[0]
+    feature_list = parse_registered_feature_ids(ua_string)
+    for feature_id in expected_feature_ids:
+        assert feature_id in feature_list
