@@ -499,6 +499,50 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
         rendered = help_command.doc.getvalue().decode('utf-8')
         self.assertRegex(rendered, r'FooBar[\s\S]*Tagged Union')
 
+    def test_documents_required_parameters(self):
+        """Tests that required parameters are correctly documented."""
+        shape_map = {
+            'ParentStructure': {
+                'type': 'structure',
+                'required': ['RequiredParameter'],
+                'members': {
+                    'RequiredParameter': {'shape': 'StringMember'},
+                    'OptionalParameter': {'shape': 'StringMember'},
+                },
+            },
+            'StringMember': {'type': 'string'},
+        }
+
+        resolver = ShapeResolver(shape_map)
+        parent_shape = StructureShape(
+            'ParentStructure', shape_map['ParentStructure'], resolver
+        )
+
+        rendered = self.get_help_docs_for_argument(parent_shape)
+
+        required_index = rendered.find('RequiredParameter -> (string)')
+        optional_index = rendered.find('OptionalParameter -> (string)')
+
+        self.assertIn('[required]', rendered[required_index:optional_index])
+        optional_text = rendered[optional_index:]
+        self.assertNotIn('[required]', optional_text)
+
+    def test_documents_constraints(self):
+        shape = {'type': 'string', 'min': 0, 'max': 10, 'pattern': '.*'}
+        shape = StringShape('ConstrainedArg', shape)
+        arg = CustomArgument('ConstrainedArg', argument_model=shape)
+        help_command = self.create_help_command()
+        help_command.arg_table = {'ConstrainedArg': arg}
+        operation_handler = OperationDocumentEventHandler(help_command)
+        operation_handler.doc_option(
+            arg_name='ConstrainedArg', help_command=help_command
+        )
+        rendered = help_command.doc.getvalue().decode('utf-8')
+        self.assertIn('Constraints', rendered)
+        self.assertIn('min: ``0``', rendered)
+        self.assertIn('max: ``10``', rendered)
+        self.assertIn('pattern: ``.*``', rendered)
+
 
 class TestTopicDocumentEventHandlerBase(unittest.TestCase):
     def setUp(self):
@@ -529,7 +573,7 @@ class TestTopicDocumentEventHandlerBase(unittest.TestCase):
 
 class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
     def setUp(self):
-        super(TestTopicListerDocumentEventHandler, self).setUp()
+        super().setUp()
         self.descriptions = [
             'This describes the first topic',
             'This describes the second topic',
@@ -571,7 +615,7 @@ class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
     def test_title(self):
         self.doc_handler.doc_title(self.cmd)
         title_contents = self.cmd.doc.getvalue().decode('utf-8')
-        self.assertIn('.. _cli:aws help %s:' % self.cmd.name, title_contents)
+        self.assertIn(f'.. _cli:aws help {self.cmd.name}:', title_contents)
         self.assertIn('AWS CLI Topic Guide', title_contents)
 
     def test_description(self):
@@ -585,12 +629,11 @@ class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
         ref_output = [
             '-------\nGeneral\n-------',
             (
-                '* topic-name-1: %s\n'
-                '* topic-name-3: %s\n'
-                % (self.descriptions[0], self.descriptions[2])
+                f'* topic-name-1: {self.descriptions[0]}\n'
+                f'* topic-name-3: {self.descriptions[2]}\n'
             ),
             '--\nS3\n--',
-            '* topic-name-2: %s\n' % self.descriptions[1],
+            f'* topic-name-2: {self.descriptions[1]}\n',
         ]
 
         self.doc_handler.doc_subitems_start(self.cmd)
@@ -606,14 +649,12 @@ class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
         ref_output = [
             '-------\nGeneral\n-------',
             (
-                '* :ref:`topic-name-1 <cli:aws help topic-name-1>`: %s\n'
-                '* :ref:`topic-name-3 <cli:aws help topic-name-3>`: %s\n'
-                % (self.descriptions[0], self.descriptions[2])
+                f'* :ref:`topic-name-1 <cli:aws help topic-name-1>`: {self.descriptions[0]}\n'
+                f'* :ref:`topic-name-3 <cli:aws help topic-name-3>`: {self.descriptions[2]}\n'
             ),
             '--\nS3\n--',
             (
-                '* :ref:`topic-name-2 <cli:aws help topic-name-2>`: %s\n'
-                % self.descriptions[1]
+                f'* :ref:`topic-name-2 <cli:aws help topic-name-2>`: {self.descriptions[1]}\n'
             ),
         ]
 
@@ -629,7 +670,7 @@ class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
 
 class TestTopicDocumentEventHandler(TestTopicDocumentEventHandlerBase):
     def setUp(self):
-        super(TestTopicDocumentEventHandler, self).setUp()
+        super().setUp()
         self.name = 'topic-name-1'
         self.title = 'The first topic title'
         self.description = 'This is about the first topic'
@@ -666,7 +707,7 @@ class TestTopicDocumentEventHandler(TestTopicDocumentEventHandlerBase):
     def test_title(self):
         self.doc_handler.doc_title(self.cmd)
         title_contents = self.cmd.doc.getvalue().decode('utf-8')
-        self.assertIn('.. _cli:aws help %s:' % self.name, title_contents)
+        self.assertIn(f'.. _cli:aws help {self.name}:', title_contents)
         self.assertIn(self.title, title_contents)
 
     def test_description(self):
