@@ -284,6 +284,7 @@ class TestCliDriver:
     def setup_method(self):
         self.session = FakeSession()
         self.session.set_config_variable('cli_auto_prompt', 'off')
+        self.session.set_config_variable('cli_help_output', None)
         self.driver = CLIDriver(session=self.session)
 
     def test_session_can_be_passed_in(self):
@@ -418,6 +419,7 @@ class TestCliDriverHooks(unittest.TestCase):
     def setUp(self):
         self.session = FakeSession()
         self.session.set_config_variable('cli_auto_prompt', 'off')
+        self.session.set_config_variable('cli_help_output', None)
         self.emitter = mock.Mock()
         self.emitter.emit.return_value = []
         self.stdout = StringIO()
@@ -499,10 +501,10 @@ class TestCliDriverHooks(unittest.TestCase):
         )
         self.assertEqual(rc, 252)
         # Tell the user what went wrong.
-        self.assertIn("Invalid choice: 'list-objecst'", self.stderr.getvalue())
+        self.assertIn("Found invalid choice 'list-objecst'", self.stderr.getvalue())
         # Offer the user a suggestion.
         self.assertIn(
-            "maybe you meant:\n\n  * list-objects", self.stderr.getvalue()
+            "Maybe you meant:\n\n  * list-objects", self.stderr.getvalue()
         )
 
 
@@ -970,6 +972,7 @@ class TestServiceCommand(unittest.TestCase):
     def setUp(self):
         self.name = 'foo'
         self.session = FakeSession()
+        self.session.set_config_variable('cli_help_output', None)
         self.cmd = ServiceCommand(self.name, self.session)
 
     def test_can_access_subcommand_table(self):
